Runs agent based modeling for one replicate of a single species.
energySIM_helper(
sp,
env_orig,
env_subtract,
days,
sigma,
dest_x,
dest_y,
mot_x,
mot_y,
search_radius,
optimum_lo,
optimum_hi,
init_energy,
direction,
single_rast,
mortality,
energy_adj
)A nx3 dataset containing longitude and latitude and energy points for all n timesteps
A species object
Raster
Raster
Integer, how many days (timesteps), would you like to model
Numeric, amount of random error
Numeric, destination x coordinate (longitude)
Numeric, destination y coordinate (latitude)
Numeric, movement motivation in x direction
Numeric, movement motivation in y direction
Radius of semicircle to South of current location to search for next timestep (in km)
come back
come back
come back
come back
Logical, should low energy levels result in death?