Prints results from moveSIM() or energySIM() in an easier-to-read table.
tidy_results(data, type = "results", nrows = NULL)Prints a cleaned table of moveSIM() or energySIM() results.
The output from moveSIM() or energySIM() -- a list of two dataframes.
"run_params" or "results", corresponding to which component of your moveSIM() or energySIM() output you'd like to print out. Default "results", which contains the movement data.
The number of rows to print.
missing_pct and mortality_pct are not function paramet?ers, but are nonetheless computed and returned here for your convenience
missing_pct: What percent of rows exhibiting a missing location value (due to agent death or agent stopping)
mortality_pct: What percent of simulated agents experienced death?